# Synago

A framework for building LLM based multi-agent system.

## Installation

```bash
# Install with the built-in tools
pip install synago[tool]
```

See the [examples](examples) folder for more details.
